==> types_boto3_cloudwatch-1.35.74-py3-none-any.whl: types_boto3_cloudwatch/waiter.py <==
"""
Type annotations for cloudwatch service client waiters.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/waiters/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_cloudwatch.client import CloudWatchClient
    from types_boto3_cloudwatch.waiter import (
        AlarmExistsWaiter,
        CompositeAlarmExistsWaiter,
    )

    session = Session()
    client: CloudWatchClient = session.client("cloudwatch")

    alarm_exists_waiter: AlarmExistsWaiter = client.get_waiter("alarm_exists")
    composite_alarm_exists_waiter: CompositeAlarmExistsWaiter = client.get_waiter("composite_alarm_exists")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys

from botocore.waiter import Waiter

from .type_defs import (
    DescribeAlarmsInputAlarmExistsWaitTypeDef,
    DescribeAlarmsInputCompositeAlarmExistsWaitTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("AlarmExistsWaiter", "CompositeAlarmExistsWaiter")


class AlarmExistsWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/waiter/AlarmExists.html#CloudWatch.Waiter.AlarmExists)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/waiters/#alarmexistswaiter)
    """

    def wait(self, **kwargs: Unpack[DescribeAlarmsInputAlarmExistsWaitTypeDef]) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/waiter/AlarmExists.html#CloudWatch.Waiter.AlarmExists.wait)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/waiters/#alarmexistswaiter)
        """


class CompositeAlarmExistsWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/waiter/CompositeAlarmExists.html#CloudWatch.Waiter.CompositeAlarmExists)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/waiters/#compositealarmexistswaiter)
    """

    def wait(self, **kwargs: Unpack[DescribeAlarmsInputCompositeAlarmExistsWaitTypeDef]) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/waiter/CompositeAlarmExists.html#CloudWatch.Waiter.CompositeAlarmExists.wait)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/waiters/#compositealarmexistswaiter)
        """

==> types_boto3_cloudwatch-1.35.93-py3-none-any.whl: types_boto3_cloudwatch/waiter.py <==
"""
Type annotations for cloudwatch service client waiters.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/waiters/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_cloudwatch.client import CloudWatchClient
    from types_boto3_cloudwatch.waiter import (
        AlarmExistsWaiter,
        CompositeAlarmExistsWaiter,
    )

    session = Session()
    client: CloudWatchClient = session.client("cloudwatch")

    alarm_exists_waiter: AlarmExistsWaiter = client.get_waiter("alarm_exists")
    composite_alarm_exists_waiter: CompositeAlarmExistsWaiter = client.get_waiter("composite_alarm_exists")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys

from botocore.waiter import Waiter

from .type_defs import DescribeAlarmsInputWaitTypeDef

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("AlarmExistsWaiter", "CompositeAlarmExistsWaiter")


class AlarmExistsWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/waiter/AlarmExists.html#CloudWatch.Waiter.AlarmExists)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/waiters/#alarmexistswaiter)
    """

    def wait(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeAlarmsInputWaitTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/waiter/AlarmExists.html#CloudWatch.Waiter.AlarmExists.wait)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/waiters/#alarmexistswaiter)
        """


class CompositeAlarmExistsWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/waiter/CompositeAlarmExists.html#CloudWatch.Waiter.CompositeAlarmExists)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/waiters/#compositealarmexistswaiter)
    """

    def wait(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeAlarmsInputWaitTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/waiter/CompositeAlarmExists.html#CloudWatch.Waiter.CompositeAlarmExists.wait)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/waiters/#compositealarmexistswaiter)
        """
